import { TypeRampValues } from '@genesislcap/foundation-utils';
import { parseColorHexRGB } from '@microsoft/fast-colors';
import { SwatchRGB, PaletteRGB, baseLayerLuminance, neutralPalette, accentPalette, density, controlCornerRadius, strokeWidth, designUnit, bodyFont, typeRampBaseFontSize, typeRampBaseLineHeight, typeRampMinus1FontSize, typeRampMinus1LineHeight, typeRampMinus2FontSize, typeRampMinus2LineHeight, typeRampPlus1FontSize, typeRampPlus1LineHeight, typeRampPlus2FontSize, typeRampPlus2LineHeight, typeRampPlus3FontSize, typeRampPlus3LineHeight, typeRampPlus4FontSize, typeRampPlus4LineHeight, typeRampPlus5FontSize, typeRampPlus5LineHeight, typeRampPlus6FontSize, typeRampPlus6LineHeight, } from '@microsoft/fast-components';
export const swatchFromColor = (hexColor) => {
    const color = parseColorHexRGB(hexColor);
    if (color) {
        return SwatchRGB.from(color);
    }
    return null;
};
export const paletteFromColor = (hexColor) => {
    const swatch = swatchFromColor(hexColor);
    if (swatch) {
        return PaletteRGB.create(swatch);
    }
    return null;
};
export const getTypeRampSize = (baseTypeRamp, value, provider) => {
    const regex = /^(\d+)([a-z]+)/i;
    const matches = baseTypeRamp.getValueFor(provider).match(regex);
    const baseFontValue = matches[1];
    const baseUnit = matches[2];
    const typeRampSize = Number(baseFontValue) + value;
    return typeRampSize + baseUnit;
};
export const applyStyleChanges = (detail, provider) => {
    const neutral = paletteFromColor(detail.neutralColor);
    neutralPalette.setValueFor(provider, neutral);
    const accent = paletteFromColor(detail.accentColor);
    accentPalette.setValueFor(provider, accent);
    baseLayerLuminance.setValueFor(provider, detail.luminance);
    density.setValueFor(provider, detail.density);
    controlCornerRadius.setValueFor(provider, detail.borderRadius);
    strokeWidth.setValueFor(provider, detail.strokeWidth);
    designUnit.setValueFor(provider, detail.designUnit);
    bodyFont.setValueFor(provider, detail.bodyFont);
    typeRampBaseFontSize.setValueFor(provider, detail.baseFontSize);
    typeRampBaseLineHeight.setValueFor(provider, detail.baseLineHeight);
    typeRampMinus1FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.minusOne, provider));
    typeRampMinus1LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.minusOne, provider));
    typeRampMinus2FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.minusTwo, provider));
    typeRampMinus2LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.minusTwo, provider));
    typeRampPlus1FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusOne, provider));
    typeRampPlus1LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusOne, provider));
    typeRampPlus2FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusTwo, provider));
    typeRampPlus2LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusTwo, provider));
    typeRampPlus3FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusThree, provider));
    typeRampPlus3LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusThree, provider));
    typeRampPlus4FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusFour, provider));
    typeRampPlus4LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusFour, provider));
    typeRampPlus5FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusFive, provider));
    typeRampPlus5LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusFive, provider));
    typeRampPlus6FontSize.setValueFor(provider, getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusSix, provider));
    typeRampPlus6LineHeight.setValueFor(provider, getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusSix, provider));
};
